==> cayenne-3.0.2-src.tar.gz: cayenne-3.0.2-src/framework/cayenne-jdk1.5-unpublished/src/main/java/org/apache/cayenne/dba/hsqldb/HSQLDBSniffer.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.dba.hsqldb;

import java.sql.DatabaseMetaData;
import java.sql.SQLException;

import org.apache.cayenne.dba.DbAdapter;
import org.apache.cayenne.dba.DbAdapterFactory;

/**
 * Detects HSQLDB database from JDBC metadata.
 * 
 * @since 1.2
 */
public class HSQLDBSniffer implements DbAdapterFactory {

    public DbAdapter createAdapter(DatabaseMetaData md) throws SQLException {
        String dbName = md.getDatabaseProductName();
        if (dbName == null || !dbName.toUpperCase().contains("HSQL")) {
            return null;
        }

        boolean supportsSchema = false;
        if (md.getDriverMajorVersion() < 1) {
            supportsSchema = true;
        }
        else if (md.getDriverMajorVersion() == 1) {
            if (md.getDriverMinorVersion() <= 8) {
                supportsSchema = true;
            }
            else {
                supportsSchema = false;
            }
        }
        else {
            supportsSchema = false;
        }
        
        return supportsSchema
            ? new HSQLDBAdapter()
            : new HSQLDBNoSchemaAdapter();
    }
}

==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/framework/cayenne-jdk1.5-unpublished/src/main/java/org/apache/cayenne/dba/hsqldb/HSQLDBSniffer.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.dba.hsqldb;

import java.sql.DatabaseMetaData;
import java.sql.SQLException;

import org.apache.cayenne.configuration.server.DbAdapterDetector;
import org.apache.cayenne.dba.DbAdapter;
import org.apache.cayenne.dba.DbAdapterFactory;
import org.apache.cayenne.di.AdhocObjectFactory;
import org.apache.cayenne.di.Inject;

/**
 * Detects HSQLDB database from JDBC metadata.
 * 
 * @since 1.2
 */
public class HSQLDBSniffer implements DbAdapterFactory, DbAdapterDetector {
    
    protected AdhocObjectFactory objectFactory;
    
    public HSQLDBSniffer(@Inject AdhocObjectFactory objectFactory) {
        this.objectFactory = objectFactory;
    }

    public DbAdapter createAdapter(DatabaseMetaData md) throws SQLException {
        String dbName = md.getDatabaseProductName();
        if (dbName == null || !dbName.toUpperCase().contains("HSQL")) {
            return null;
        }

        boolean supportsSchema = false;
        if (md.getDriverMajorVersion() < 1) {
            supportsSchema = true;
        }
        else if (md.getDriverMajorVersion() == 1) {
            if (md.getDriverMinorVersion() <= 8) {
                supportsSchema = true;
            }
            else {
                supportsSchema = false;
            }
        }
        else {
            supportsSchema = false;
        }
        
        return supportsSchema
            ? (DbAdapter)objectFactory.newInstance(DbAdapter.class, HSQLDBAdapter.class.getName())
            : (DbAdapter)objectFactory.newInstance(
                    DbAdapter.class, 
                    HSQLDBNoSchemaAdapter.class.getName());
    }
}
